==> module-common-1.1.2-sources.jar: com/sygic/maps/module/common/provider/ModuleConnectionProvider.kt <==
/*
 * Copyright (c) 2019 Sygic a.s. All rights reserved.
 *
 * This project is licensed under the MIT License.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */

package com.sygic.maps.module.common.provider

import androidx.annotation.RestrictTo
import androidx.fragment.app.Fragment
import androidx.lifecycle.LiveData

/**
 * Interface definition designed for a independent module connection.
 */
interface ModuleConnectionProvider {

    /**
     * A *[fragment]* to be used as a target for the transaction.
     *
     * @param [Fragment] target fragment.
     *
     */
    val fragment: Fragment
}

@RestrictTo(RestrictTo.Scope.LIBRARY_GROUP)
interface ModuleConnectionProviderWrapper {
    val moduleConnectionProvider: LiveData<ModuleConnectionProvider>
}

==> module-common-1.4.0-sources.jar: com/sygic/maps/module/common/provider/ModuleConnectionProvider.kt <==
/*
 * Copyright (c) 2019 Sygic a.s. All rights reserved.
 *
 * This project is licensed under the MIT License.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */

package com.sygic.maps.module.common.provider

import androidx.annotation.RestrictTo
import androidx.fragment.app.Fragment
import androidx.lifecycle.LiveData

/**
 * Interface definition designed for a independent module connection.
 */
interface ModuleConnectionProvider {

    /**
     * A *[fragment]* to be used as a target for the transaction.
     *
     * @param [Fragment] target fragment.
     *
     */
    val fragment: Fragment

    /**
     * The [Fragment] tag to be used as a target tag for the transaction.
     *
     * @param [String] target tag.
     *
     */
    fun getFragmentTag(): String? = null
}

@RestrictTo(RestrictTo.Scope.LIBRARY_GROUP)
interface ModuleConnectionProviderWrapper {
    val moduleConnectionProvidersMap: LiveData<Map<ProviderType, ModuleConnectionProvider?>>
}
